==> huaweicloudsdkelb-3.1.55-py2.py3-none-any.whl: huaweicloudsdkelb/v2/model/update_whitelist_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateWhitelistRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'whitelist_id': 'str',
        'body': 'UpdateWhitelistRequestBody'
    }

    attribute_map = {
        'whitelist_id': 'whitelist_id',
        'body': 'body'
    }

    def __init__(self, whitelist_id=None, body=None):
        """UpdateWhitelistRequest

        The model defined in huaweicloud sdk

        :param whitelist_id: 待更新的白名单id
        :type whitelist_id: str
        :param body: Body of the UpdateWhitelistRequest
        :type body: :class:`huaweicloudsdkelb.v2.UpdateWhitelistRequestBody`
        """
        
        

        self._whitelist_id = None
        self._body = None
        self.discriminator = None

        self.whitelist_id = whitelist_id
        if body is not None:
            self.body = body

    @property
    def whitelist_id(self):
        """Gets the whitelist_id of this UpdateWhitelistRequest.

        待更新的白名单id

        :return: The whitelist_id of this UpdateWhitelistRequest.
        :rtype: str
        """
        return self._whitelist_id

    @whitelist_id.setter
    def whitelist_id(self, whitelist_id):
        """Sets the whitelist_id of this UpdateWhitelistRequest.

        待更新的白名单id

        :param whitelist_id: The whitelist_id of this UpdateWhitelistRequest.
        :type whitelist_id: str
        """
        self._whitelist_id = whitelist_id

    @property
    def body(self):
        """Gets the body of this UpdateWhitelistRequest.

        :return: The body of this UpdateWhitelistRequest.
        :rtype: :class:`huaweicloudsdkelb.v2.UpdateWhitelistRequestBody`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this UpdateWhitelistRequest.

        :param body: The body of this UpdateWhitelistRequest.
        :type body: :class:`huaweicloudsdkelb.v2.UpdateWhitelistRequestBody`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateWhitelistRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkelb-3.1.152-py2.py3-none-any.whl: huaweicloudsdkelb/v2/model/update_whitelist_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateWhitelistRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'whitelist_id': 'str',
        'body': 'UpdateWhitelistRequestBody'
    }

    attribute_map = {
        'whitelist_id': 'whitelist_id',
        'body': 'body'
    }

    def __init__(self, whitelist_id=None, body=None):
        r"""UpdateWhitelistRequest

        The model defined in huaweicloud sdk

        :param whitelist_id: 待更新的白名单id
        :type whitelist_id: str
        :param body: Body of the UpdateWhitelistRequest
        :type body: :class:`huaweicloudsdkelb.v2.UpdateWhitelistRequestBody`
        """
        
        

        self._whitelist_id = None
        self._body = None
        self.discriminator = None

        self.whitelist_id = whitelist_id
        if body is not None:
            self.body = body

    @property
    def whitelist_id(self):
        r"""Gets the whitelist_id of this UpdateWhitelistRequest.

        待更新的白名单id

        :return: The whitelist_id of this UpdateWhitelistRequest.
        :rtype: str
        """
        return self._whitelist_id

    @whitelist_id.setter
    def whitelist_id(self, whitelist_id):
        r"""Sets the whitelist_id of this UpdateWhitelistRequest.

        待更新的白名单id

        :param whitelist_id: The whitelist_id of this UpdateWhitelistRequest.
        :type whitelist_id: str
        """
        self._whitelist_id = whitelist_id

    @property
    def body(self):
        r"""Gets the body of this UpdateWhitelistRequest.

        :return: The body of this UpdateWhitelistRequest.
        :rtype: :class:`huaweicloudsdkelb.v2.UpdateWhitelistRequestBody`
        """
        return self._body

    @body.setter
    def body(self, body):
        r"""Sets the body of this UpdateWhitelistRequest.

        :param body: The body of this UpdateWhitelistRequest.
        :type body: :class:`huaweicloudsdkelb.v2.UpdateWhitelistRequestBody`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateWhitelistRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
